@@ -67,12 +67,16 @@ class Runner(Authenticate):
         for k in inputs.keys():
             if k in asset_keys:
                 asset[k] = inputs[k]
-
-        for k in asset_keys:
+        for k in asset.keys():
             del inputs[k]
 
         return asset, inputs
 
+    def get_headers(self):
+        return self.session.headers.update({
+            self.inputs.get('headers', {})
+        })
+
     def get_endpoint(self):
         # Mustache if available if not returns string as is.
         return chevron.render(self.endpoint, self.inputs.get('path_parameters', {}))
@@ -93,7 +97,7 @@ class Runner(Authenticate):
             json_body = {}
 
         # todo: can we handle files automatically?
-        # todo: should we parse the raw http response? What format should we return.
+        # todo: should we parse the raw http response? What format should we return. SPIKE
 
         return {
             'status_code': response.status_code,
